@@ -31,6 +31,9 @@ class Profiles(dict):
 
         if self.path.exists():
             self.load()
+        else:
+            # Try loading a default profile using environment variables
+            self.load_from_env()
 
     def load(self) -> None:
         try:
@@ -46,6 +49,14 @@ class Profiles(dict):
         self.default_profile_name = data.get("default_host")
         self.gpg_key = data.get("gpg_key")
 
+    def load_from_env(self) -> None:
+        # Try creating a new profile using environment variables
+        arkindex_api = os.environ.get("ARKINDEX_API_URL")
+        arkindex_token = os.environ.get("ARKINDEX_API_TOKEN")
+        if arkindex_api and arkindex_token:
+            self.add_profile(slug="env", url=arkindex_api, token=arkindex_token)
+            self.set_default_profile("env")
+
     def get_default_profile(self) -> Optional[Profile]:
         if self.default_profile_name in self:
             return self[self.default_profile_name]
