@@ -8,7 +8,9 @@ import pkg_resources
 from arkindex_cli.commands.benchmark import add_benchmark_parser
 from arkindex_cli.commands.classes import add_classes_parser
 from arkindex_cli.commands.elements import add_elements_parser
+from arkindex_cli.commands.export import add_export_parser
 from arkindex_cli.commands.login import add_login_parser
+from arkindex_cli.commands.models import add_models_parser
 from arkindex_cli.commands.process import add_process_parser
 from arkindex_cli.commands.secrets import add_secrets_parser
 from arkindex_cli.commands.upload import add_upload_parser
@@ -47,13 +49,15 @@ def get_parser():
 
     subcommands = parser.add_subparsers(metavar="subcommand")
 
-    add_login_parser(subcommands)
-    add_process_parser(subcommands)
     add_benchmark_parser(subcommands)
     add_classes_parser(subcommands)
+    add_elements_parser(subcommands)
+    add_export_parser(subcommands)
+    add_login_parser(subcommands)
+    add_process_parser(subcommands)
     add_secrets_parser(subcommands)
     add_upload_parser(subcommands)
-    add_elements_parser(subcommands)
+    add_models_parser(subcommands)
 
     return parser
 
