@@ -32,7 +32,7 @@ def run(
     while not host:
         parser = URLArgument(allow_query=False, allow_fragment=False)
         try:
-            host = parser(ask("Arkindex instance URL", default="arkindex.teklia.com"))
+            host = parser(ask("Arkindex instance URL", default="demo.arkindex.org"))
         except ValueError as e:
             print(f"[bright_red]{e}")
 
